# CHANGELOG

<!-- version list -->

## v1.2.1 (2025-10-13)

### Bug Fixes

- Resolve file path issues in get_changed_files for git diff
  ([`279d54a`](https://github.com/you-n-g/toolbox/commit/279d54a4f712c963294b1d37771b0696a5334630))


## v1.2.0 (2025-06-28)

### Chores

- Update project description with GitHub URL
  ([`488dd90`](https://github.com/you-n-g/toolbox/commit/488dd908cd4ce1f95d825dc9901759c65af0727a))

### Documentation

- Update README and pyproject metadata
  ([`0df7965`](https://github.com/you-n-g/toolbox/commit/0df79652e8d9adf4503f38bcb12d868f0a1bc5f8))

### Features

- Add design feedback
  ([`124f780`](https://github.com/you-n-g/toolbox/commit/124f780b073137b2c04d66ab7e874ad4789d7a5e))


## v1.1.0 (2025-06-28)

### Build System

- Add uv publish step to release target
  ([`9868264`](https://github.com/you-n-g/toolbox/commit/9868264fc2e76a6de3bf088d723116b527b60f13))

- Switch to setuptools-scm and update build targets
  ([`d157100`](https://github.com/you-n-g/toolbox/commit/d1571007d0c16cb15b6fea8474b543cf8a9bc401))

### Chores

- Use uvx for build/release, ignore .uv, enable dynamic version
  ([`713ba4f`](https://github.com/you-n-g/toolbox/commit/713ba4fdc73a05dac14ca268f9345bfd78287cc2))

### Features

- Add xytb code review CLI and update project dependencies
  ([`cc6bc3a`](https://github.com/you-n-g/toolbox/commit/cc6bc3a26c2c7d1db277a2f3da8f1daec4c65851))


## v1.0.0 (2025-06-28)

- Initial Release
